@@ -6,9 +6,9 @@ use warnings;
 #use utf8;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-27'; # DATE
+our $DATE = '2021-08-28'; # DATE
 our $DIST = 'Text-Table-More'; # DIST
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 # see Module::Features for more details on this
 our %FEATURES = (
@@ -621,7 +621,7 @@ Text::Table::More - Generate text table with simple interface and many options
 
 =head1 VERSION
 
-This document describes version 0.019 of Text::Table::More (from Perl distribution Text-Table-More), released on 2021-08-27.
+This document describes version 0.020 of Text::Table::More (from Perl distribution Text-Table-More), released on 2021-08-28.
 
 =head1 SYNOPSIS
 
@@ -1061,7 +1061,7 @@ Arguments:
 
 Array of arrayrefs (of strings or hashrefs). Required. Each array element is a
 row of cells. A cell can be a string like C<"foo"> specifying only the text
-(equivalent to C<<{ text=>"foo" >>) or a hashref which allows you to specify a
+(equivalent to C<< {text=>"foo"} >>) or a hashref which allows you to specify a
 cell's text (C<text>) as well as attributes like C<rowspan> (int, >= 1),
 C<colspan> (int, >= 1), etc. See L</PER-CELL ATTRIBUTES> for the list of known
 per-cell attributes.
